@@ -383,9 +383,9 @@ _panel_icon_chooser_clicked (GtkButton *button)
 	filechooser = gtk_file_chooser_dialog_new (_("Choose an icon"),
 						   parent,
 						   GTK_FILE_CHOOSER_ACTION_OPEN,
-						   GTK_STOCK_CANCEL,
+						   _("_Cancel"),
 						   GTK_RESPONSE_CANCEL,
-						   GTK_STOCK_OPEN,
+						   _("_Open"),
 						   GTK_RESPONSE_ACCEPT,
 						   NULL);
 	panel_gtk_file_chooser_add_image_preview (GTK_FILE_CHOOSER (filechooser));
@@ -400,10 +400,10 @@ _panel_icon_chooser_clicked (GtkButton *button)
 					      path, NULL);
 	g_free (path);
 
+	path = NULL;
 	filechooser_path_set = FALSE;
 
 	if (chooser->priv->icon) {
-		char *path = NULL;
 		if (g_path_is_absolute (chooser->priv->icon)) {
 			path = g_strdup (chooser->priv->icon);
 		} else {
@@ -436,12 +436,12 @@ _panel_icon_chooser_clicked (GtkButton *button)
 	}
 
 	if (!filechooser_path_set) {
-		char *path;
 		// FIXME? Use current icon theme? But there might not be a lot
 		// of icons there...
 		path = g_build_filename (DATADIR, "icons", NULL);
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (filechooser),
 						     path);
+		g_free (path);
 	}
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (filechooser), TRUE);
