@@ -62,9 +62,6 @@ struct _PanelAppletFrameClass {
 	void     (*change_orientation)    (PanelAppletFrame    *frame,
 					   PanelOrientation     orientation);
 
-	void     (*change_size)           (PanelAppletFrame    *frame,
-					   guint                size);
-
 	void     (*change_background)     (PanelAppletFrame    *frame,
 					   PanelBackgroundType  type);
 };
@@ -89,12 +86,6 @@ void  panel_applet_frame_load               (PanelWidget         *panel_widget,
 void  panel_applet_frame_change_orientation (PanelAppletFrame    *frame,
 					     PanelOrientation     orientation);
 
-void  panel_applet_frame_change_size        (PanelAppletFrame    *frame,
-					     guint                size);
-
-void  panel_applet_frame_change_background  (PanelAppletFrame    *frame,
-					     PanelBackgroundType  type);
-
 void  panel_applet_frame_set_panel          (PanelAppletFrame    *frame,
 					     PanelWidget         *panel);
 
@@ -105,10 +96,8 @@ typedef struct _PanelAppletFrameActivating        PanelAppletFrameActivating;
 
 GdkScreen        *panel_applet_frame_activating_get_screen      (PanelAppletFrameActivating *frame_act);
 PanelOrientation  panel_applet_frame_activating_get_orientation (PanelAppletFrameActivating *frame_act);
-guint32           panel_applet_frame_activating_get_size        (PanelAppletFrameActivating *frame_act);
 gboolean          panel_applet_frame_activating_get_locked_down (PanelAppletFrameActivating *frame_act);
 gchar            *panel_applet_frame_activating_get_settings_path (PanelAppletFrameActivating *frame_act);
-gchar            *panel_applet_frame_activating_get_conf_path   (PanelAppletFrameActivating *frame_act);
 
 void  _panel_applet_frame_set_iid               (PanelAppletFrame           *frame,
 						 const gchar                *iid);
