@@ -93,12 +93,24 @@ static void panel_menu_button_set_icon              (PanelMenuButton *button);
 
 static AtkObject *panel_menu_button_get_accessible  (GtkWidget       *widget);
 
+static void
+fix_application_menu_name (void)
+{
+	static gboolean updated = FALSE;
+	if (!updated) {
+		root_items [0].filename = get_applications_menu ();
+		updated = TRUE;
+	}
+}
+
 static const char *
 panel_menu_path_root_to_filename (MenuPathRoot path_root)
 {
 	const char *retval;
 	int         i;
 
+	fix_application_menu_name ();
+
 	retval = NULL;
 
 	for (i = 0; i < G_N_ELEMENTS (root_items); i++) {
@@ -117,6 +129,8 @@ panel_menu_filename_to_scheme (const char *filename)
 	const char *retval;
 	int         i;
 
+	fix_application_menu_name ();
+
 	retval = NULL;
 	
 	if (!filename)
@@ -140,6 +154,8 @@ panel_menu_scheme_to_path_root (const char *scheme)
 	MenuPathRoot retval;
 	int          i;
 
+	fix_application_menu_name ();
+
 	retval = LAST_MENU;
 	
 	if (!scheme)
@@ -555,7 +571,7 @@ panel_menu_button_load_helper (const char  *menu_path,
 
         if (panel_is_program_in_path ("alacarte") ||
 	    panel_is_program_in_path ("gmenu-simple-editor"))
-		panel_applet_add_callback (info, "edit", NULL,
+		panel_applet_add_callback (info, "edit",
 					   _("_Edit Menus"),
 					   panel_lockdown_get_not_panels_locked_down_s);
 
