@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
 
  * Authors:
  *	Mark McLoughlin <mark@skynet.ie>
@@ -56,7 +54,6 @@ typedef struct {
 	GtkWidget     *image_widgets;
 	GtkWidget     *color_button;
 	GtkWidget     *image_chooser;
-	GtkWidget     *opacity_scale;
 
 	GtkWidget     *writability_warn_general;
 	GtkWidget     *writability_warn_background;
@@ -92,7 +89,7 @@ panel_properties_size_spin_update_range (PanelPropertiesDialog *dialog)
 		return;
 
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (dialog->size_spin),
-				   panel_toplevel_get_minimum_size (dialog->toplevel),
+				   16,
 				   panel_toplevel_get_maximum_size (dialog->toplevel));
 }
 
@@ -170,7 +167,7 @@ panel_properties_dialog_setup_orientation_combo (PanelPropertiesDialog *dialog,
 	GtkListStore     *model;
 	GtkTreeIter       iter;
 	GtkCellRenderer  *renderer;
-	int               i;
+	guint             i;
 
 	dialog->orientation_combo = PANEL_GTK_BUILDER_GET (gui, "orientation_combo");
 	g_return_if_fail (dialog->orientation_combo != NULL);
@@ -406,147 +403,55 @@ panel_properties_dialog_image_chooser_setup (PanelPropertiesDialog *dialog,
  * Background color *
 \********************/
 
-static void
-panel_properties_dialog_background_color_get_rgba (PanelPropertiesDialog *dialog,
-						   GdkRGBA               *color)
+static gboolean
+get_color (GValue   *value,
+           GVariant *variant,
+           gpointer  user_data)
 {
-	char *color_str;
+	const gchar *color;
+	GdkRGBA rgba;
 
-	color_str = g_settings_get_string (dialog->settings_background,
-					   PANEL_BACKGROUND_COLOR_KEY);
+	color = g_variant_get_string (variant, NULL);
 
-	if (!gdk_rgba_parse (color, color_str))
-		gdk_rgba_parse (color, PANEL_BACKGROUND_COLOR_DEFAULT);
-	g_free (color_str);
+	if (!gdk_rgba_parse (&rgba, color))
+		return FALSE;
+
+	g_value_set_boxed (value, &rgba);
+
+	return TRUE;
 }
 
-static void
-panel_properties_dialog_background_color_update_from_rgba (PanelPropertiesDialog *dialog,
-							   GdkRGBA               *color)
+static GVariant *
+set_color (const GValue       *value,
+           const GVariantType *expected_type,
+           gpointer            user_data)
 {
-	/* note: we might not be fully setup, so we have to do checks */
-	if (dialog->opacity_scale)
-		gtk_range_set_value (GTK_RANGE (dialog->opacity_scale),
-				     color->alpha * 100.);
-	if (dialog->color_button)
-		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (dialog->color_button),
-					   color);
-}
+	GdkRGBA *rgba;
+	gchar *color;
+	GVariant *variant;
 
-static void
-panel_properties_dialog_background_color_set_from_rgba (PanelPropertiesDialog *dialog,
-							GdkRGBA               *color)
-{
-	char *color_str;
+	rgba = g_value_get_boxed (value);
+	color = gdk_rgba_to_string (rgba);
 
-	color_str = gdk_rgba_to_string (color);
-	g_settings_set_string (dialog->settings_background,
-			       PANEL_BACKGROUND_COLOR_KEY, color_str);
-	g_free (color_str);
+	variant = g_variant_new_string (color);
+	g_free (color);
 
-	/* make sure all widgets are consistent */
-	panel_properties_dialog_background_color_update_from_rgba (dialog, color);
-}
-
-static void
-panel_properties_dialog_background_color_update (PanelPropertiesDialog *dialog)
-{
-	GdkRGBA color;
-
-	panel_properties_dialog_background_color_get_rgba (dialog, &color);
-	panel_properties_dialog_background_color_update_from_rgba (dialog, &color);
-}
-
-static void
-panel_properties_dialog_color_button_changed (PanelPropertiesDialog *dialog,
-					      GtkColorChooser        *color_button)
-{
-	GdkRGBA old_color;
-	GdkRGBA new_color;
-
-	panel_properties_dialog_background_color_get_rgba (dialog, &old_color);
-	gtk_color_chooser_get_rgba (color_button, &new_color);
-	new_color.alpha = old_color.alpha;
-	panel_properties_dialog_background_color_set_from_rgba (dialog, &new_color);
+	return variant;
 }
 
 static void
 panel_properties_dialog_color_button_setup (PanelPropertiesDialog *dialog,
 					    GtkBuilder            *gui)
 {
-	GtkWidget *color_label;
-
 	dialog->color_button = PANEL_GTK_BUILDER_GET (gui, "color_button");
 	g_return_if_fail (dialog->color_button != NULL);
-	color_label = PANEL_GTK_BUILDER_GET (gui, "color_label");
-	g_return_if_fail (color_label != NULL);
 
-	panel_properties_dialog_background_color_update (dialog);
-
-	g_signal_connect_swapped (dialog->color_button, "color_set",
-				  G_CALLBACK (panel_properties_dialog_color_button_changed),
-				  dialog);
-
-	g_settings_bind_writable (dialog->settings_background,
-				  PANEL_BACKGROUND_COLOR_KEY,
-				  color_label, "sensitive", FALSE);
-	g_settings_bind_writable (dialog->settings_background,
-				  PANEL_BACKGROUND_COLOR_KEY,
-				  dialog->color_button, "sensitive", FALSE);
-
-	if (!g_settings_is_writable (dialog->settings_background,
-				     PANEL_BACKGROUND_COLOR_KEY))
-		gtk_widget_show (dialog->writability_warn_background);
-}
-
-
-static void
-panel_properties_dialog_opacity_scale_changed (PanelPropertiesDialog *dialog)
-{
-	gdouble percentage;
-        GdkRGBA color;
-
-	percentage = gtk_range_get_value (GTK_RANGE (dialog->opacity_scale));
-
-	if (percentage >= 98)
-		percentage = 100;
-	else if (percentage <= 2)
-		percentage = 0;
-
-	panel_properties_dialog_background_color_get_rgba (dialog, &color);
-	color.alpha = (percentage / 100.);
-	panel_properties_dialog_background_color_set_from_rgba (dialog, &color);
-}
-
-static void
-panel_properties_dialog_opacity_scale_setup (PanelPropertiesDialog *dialog,
-					     GtkBuilder            *gui)
-{
-	GtkWidget *opacity_label;
-	GtkWidget *opacity_legend;
-
-	dialog->opacity_scale = PANEL_GTK_BUILDER_GET (gui, "opacity_scale");
-	g_return_if_fail (dialog->opacity_scale != NULL);
-	opacity_label = PANEL_GTK_BUILDER_GET (gui, "opacity_label");
-	g_return_if_fail (opacity_label != NULL);
-	opacity_legend = PANEL_GTK_BUILDER_GET (gui, "opacity_legend");
-	g_return_if_fail (opacity_legend != NULL);
-
-	panel_properties_dialog_background_color_update (dialog);
-
-	g_signal_connect_swapped (dialog->opacity_scale, "value_changed",
-				  G_CALLBACK (panel_properties_dialog_opacity_scale_changed),
-				  dialog);
-
-	g_settings_bind_writable (dialog->settings_background,
-				  PANEL_BACKGROUND_COLOR_KEY,
-				  opacity_label, "sensitive", FALSE);
-	g_settings_bind_writable (dialog->settings_background,
-				  PANEL_BACKGROUND_COLOR_KEY,
-				  opacity_legend, "sensitive", FALSE);
-	g_settings_bind_writable (dialog->settings_background,
-				  PANEL_BACKGROUND_COLOR_KEY,
-				  dialog->opacity_scale, "sensitive", FALSE);
+	g_settings_bind_with_mapping (dialog->settings_background,
+	                              PANEL_BACKGROUND_COLOR_KEY,
+	                              dialog->color_button, "rgba",
+	                              G_SETTINGS_BIND_DEFAULT,
+	                              get_color, set_color,
+	                              dialog, NULL);
 
 	if (!g_settings_is_writable (dialog->settings_background,
 				     PANEL_BACKGROUND_COLOR_KEY))
@@ -672,8 +577,6 @@ panel_properties_dialog_background_changed (GSettings             *settings,
 		panel_properties_dialog_background_type_update (dialog);
 	else if (g_strcmp0 (key, PANEL_BACKGROUND_IMAGE_URI_KEY) == 0)
 		panel_properties_dialog_background_image_update (dialog);
-	else if (g_strcmp0 (key, PANEL_BACKGROUND_COLOR_KEY) == 0)
-		panel_properties_dialog_background_color_update (dialog);
 }
 
 /******************************\
@@ -766,7 +669,6 @@ panel_properties_dialog_new (PanelToplevel *toplevel,
 
 	panel_properties_dialog_image_chooser_setup     (dialog, gui);
 	panel_properties_dialog_color_button_setup      (dialog, gui);
-	panel_properties_dialog_opacity_scale_setup     (dialog, gui);
 	panel_properties_dialog_background_radios_setup (dialog, gui);
 
 	g_signal_connect (dialog->settings_background, "changed",
