@@ -35,8 +35,6 @@ struct _PanelSeparatorPrivate {
 
 	GtkOrientation  orientation;
 	GtkWidget      *separator;
-
-	unsigned char   force_background_redraw: 1;
 };
 
 G_DEFINE_TYPE (PanelSeparator, panel_separator, GTK_TYPE_EVENT_BOX)
@@ -132,17 +130,12 @@ static void
 panel_separator_size_allocate (GtkWidget     *widget,
 			       GtkAllocation *allocation)
 {
-	PanelSeparator  *separator = PANEL_SEPARATOR (widget);
-	GtkAllocation    old_allocation;
 	GtkStyleContext *context;
 	GtkStateFlags    state;
 	GtkBorder        padding;
 	GtkBorder        border;
 	GtkAllocation    new_allocation;
 	GtkWidget       *child;
-	PanelBackground *background;
-
-	gtk_widget_get_allocation (widget, &old_allocation);
 
 	GTK_WIDGET_CLASS (panel_separator_parent_class)->size_allocate (widget, allocation);
 
@@ -172,23 +165,6 @@ panel_separator_size_allocate (GtkWidget     *widget,
 	child = gtk_bin_get_child (GTK_BIN (widget));
 	if (child && gtk_widget_get_visible (child))
 		gtk_widget_size_allocate (child, &new_allocation);
-
-	if (!separator->priv->force_background_redraw &&
-	    (old_allocation.x      == allocation->x &&
-	     old_allocation.y      == allocation->y &&
-	     old_allocation.width  == allocation->width &&
-	     old_allocation.height == allocation->height))
-		return;
-
-	separator->priv->force_background_redraw = FALSE;
-
-	background = &separator->priv->panel->background;
-
-	if (background->type == PANEL_BACK_NONE ||
-	   (background->type == PANEL_BACK_COLOR && !background->has_alpha))
-		return;
-
-	panel_separator_change_background (separator);
 }
 
 static void
@@ -230,7 +206,6 @@ panel_separator_init (PanelSeparator *separator)
 	separator->priv->panel = NULL;
 	separator->priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 	separator->priv->separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
-	separator->priv->force_background_redraw = FALSE;
 
 	gtk_container_add (GTK_CONTAINER (separator),
 			   separator->priv->separator);
@@ -280,7 +255,6 @@ panel_separator_set_orientation (PanelSeparator   *separator,
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (separator->priv->separator),
 					orient_separator);
 
-	separator->priv->force_background_redraw = TRUE;
 	gtk_widget_queue_resize (GTK_WIDGET (separator));
 }
 
@@ -320,10 +294,3 @@ panel_separator_create (PanelToplevel       *toplevel,
 				    panel_toplevel_get_id (toplevel),
 				    pack_type, pack_index);
 }
-
-void
-panel_separator_change_background (PanelSeparator *separator)
-{
-	panel_background_change_background_on_widget (&separator->priv->panel->background,
-						      GTK_WIDGET (separator));
-}
