@@ -404,6 +404,28 @@ panel_applet_get_orient (PanelApplet *applet)
 	return applet->priv->orient;
 }
 
+/**
+ * panel_applet_get_gtk_orientation:
+ * @applet: a #PanelApplet
+ *
+ * Gets the #GtkOrientation of @applet.
+ *
+ * Returns: the #GtkOrientation of @applet.
+ *
+ * Since: 3.18
+ */
+GtkOrientation
+panel_applet_get_gtk_orientation (PanelApplet *applet)
+{
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), GTK_ORIENTATION_HORIZONTAL);
+
+	if (applet->priv->orient == PANEL_APPLET_ORIENT_LEFT ||
+	    applet->priv->orient == PANEL_APPLET_ORIENT_RIGHT)
+		return GTK_ORIENTATION_VERTICAL;
+
+	return GTK_ORIENTATION_HORIZONTAL;
+}
+
 /* Applets cannot set their orientation, so API is not public. */
 static void
 panel_applet_set_orient (PanelApplet      *applet,
@@ -1130,6 +1152,21 @@ panel_applet_button_release (GtkWidget      *widget,
 	return panel_applet_button_event (applet, event);
 }
 
+static void
+panel_applet_composited_changed (GtkWidget *widget)
+{
+	GdkScreen *screen;
+	GdkVisual *visual;
+
+	screen = gtk_widget_get_screen (widget);
+	visual = gdk_screen_get_rgba_visual (screen);
+
+	if (visual == NULL)
+		visual = gdk_screen_get_system_visual (screen);
+
+	gtk_widget_set_visual (widget, visual);
+}
+
 static gboolean
 panel_applet_key_press_event (GtkWidget   *widget,
 			      GdkEventKey *event)
@@ -1770,7 +1807,7 @@ panel_applet_init (PanelApplet *applet)
 
 	applet->priv->builder = gtk_builder_new ();
 
-	gchar *xml = g_strdup_printf (panel_menu_ui, N_("_Remove From Panel"), N_("_Move"));
+	gchar *xml = g_strdup_printf (panel_menu_ui, _("_Remove From Panel"), _("_Move"));
 	gtk_builder_add_from_string (applet->priv->builder, xml, -1, NULL);
 	g_free (xml);
 
@@ -1783,6 +1820,8 @@ panel_applet_init (PanelApplet *applet)
 
 	context = gtk_widget_get_style_context (GTK_WIDGET (applet));
 	gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
+
+	panel_applet_composited_changed (GTK_WIDGET (applet));
 }
 
 static GObject *
@@ -1842,6 +1881,7 @@ panel_applet_class_init (PanelAppletClass *klass)
 
 	widget_class->button_press_event = panel_applet_button_press;
 	widget_class->button_release_event = panel_applet_button_release;
+	widget_class->composited_changed = panel_applet_composited_changed;
 	widget_class->key_press_event = panel_applet_key_press_event;
 	widget_class->get_request_mode = panel_applet_get_request_mode;
         widget_class->get_preferred_width = panel_applet_get_preferred_width;
